@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: pugs-DrIFT
-version: 2.2.3.20120203
-id: pugs-DrIFT-2.2.3.20120203-4aabdce7f099dc2a7b0f8be1e93dec0e
+version: 2.2.3.20130611
+id: pugs-DrIFT-2.2.3.20130611-4db2cfdc83f10512e6428a78718918c6
 
 license: BSD3
 copyright:
@@ -26,28 +26,28 @@ exposed: True
 exposed-modules: DrIFT.JSON DrIFT.Perl5 DrIFT.Perl6Class DrIFT.YAML
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/pugs-DrIFT-2.2.3.20120203
-library-dirs: /usr/local/lib/ghc/pugs-DrIFT-2.2.3.20120203
-hs-libraries: HSpugs-DrIFT-2.2.3.20120203
+import-dirs: /usr/local/lib/ghc/pugs-DrIFT-2.2.3.20130611
+library-dirs: /usr/local/lib/ghc/pugs-DrIFT-2.2.3.20130611
+hs-libraries: HSpugs-DrIFT-2.2.3.20130611
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: HsSyck-0.50-3b2d30573d47fac28e18f956793f873a
-         base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
-         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
-         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
-         old-time-1.1.0.0-3e0f7b48d6c1d1415ad852e23725fdc1
-         pretty-1.1.1.0-867dcdeb02592f3d2a707618561c7b86
-         random-1.0.1.1-597e5fbb16214a2d52b559b0643d1749
-         stm-2.4-7929e2354ddb937b8bf4d18cb0816e56
-         utf8-string-0.3.8-d5e5121211c1ffe304a6efae5f108415
+depends: HsSyck-0.50-f3b22abe56e30455b752ce443e50852f
+         base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
+         bytestring-0.10.0.2-f858e0cb19bca2e9549882fc8424f656
+         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
+         mtl-2.1.2-735d9c92b4f214d454fb5168bb1eb6ee
+         old-time-1.1.0.1-8b10e3f99ed8611456aa344014a88da2
+         pretty-1.1.1.0-2de27f83b2c1c65d629a564e9e01b27d
+         random-1.0.1.1-e63672c93ea60d4fa26e4b5c7949f935
+         stm-2.4.2-0f41fcf17f5bc067084394f47dbfe7cf
+         utf8-string-0.3.8-123abdc63e716e348b66c892fc671d76
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-pugs-DrIFT-2.2.3.20120203/html/pugs-DrIFT.haddock
-haddock-html: /usr/local/share/doc/hs-pugs-DrIFT-2.2.3.20120203/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-pugs-DrIFT-2.2.3.20130611/html/pugs-DrIFT.haddock
+haddock-html: /usr/local/share/doc/hs-pugs-DrIFT-2.2.3.20130611/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
